error_message_ns

Function error_message_ns 

pub extern "C" fn error_message_ns(
    error_code: c_int,
) -> *const c_uchar
Returns an error message to the daemon given an error code.

If an undefined error code is provided, then this function will return a null pointer.