pub trait PluginError: Error {
// Required methods
fn new(error_code: c_int) -> Self;
fn error_code(&self) -> c_int;
}Expand description
The set of functions that must be implemented by a plugin library’s main error type.
Required Methods
Sourcefn new(error_code: c_int) -> Self
fn new(error_code: c_int) -> Self
Initializes and returns a new instace of the error type.
Arguments
error_code- One of the integer error codes recognized by KPAL.
Sourcefn error_code(&self) -> c_int
fn error_code(&self) -> c_int
Returns the error code of the instance.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".